what.models.detection.ssd API documentation

# what.models.detection.ssd

This module implements SSD object detection model.

## what.models.detection.ssd.mobilenet_v1_ssd

## what.models.detection.ssd.mobilenet_v2_ssd_lite

View Source

     1r'''
     2This module implements SSD object detection model.
     3
     4<br />
     5
     6## what.models.detection.ssd.mobilenet_v1_ssd
     7## what.models.detection.ssd.mobilenet_v2_ssd_lite
     8
     9'''
    10
    11from what.models.detection.ssd.mobilenet_v1_ssd import MobileNetV1SSD
    12from what.models.detection.ssd.mobilenet_v2_ssd_lite import MobileNetV2SSDLite